@@ -2,6 +2,7 @@
 #![cfg_attr(all(feature="nightly", feature="std"), feature(const_fn_fn_ptr_basics))]
 #![cfg_attr(feature="nightly", feature(const_fn_trait_bound))]
 //#![cfg_attr(feature="nightly", feature(const_trait_impl))]
+#![cfg_attr(all(feature="nightly", feature="std"), feature(once_cell))]
 #![cfg_attr(feature="nightly", feature(shrink_to))]
 #![cfg_attr(feature="nightly", feature(try_reserve))]
 
@@ -37,12 +38,12 @@ use core::ops::{Index, IndexMut};
 use core::sync::atomic::{AtomicBool, Ordering};
 use educe::Educe;
 use either::{Either, Left, Right};
-#[cfg(all(feature="std", feature="nightly"))]
-use once_cell::sync::{self};
 use phantom_type::PhantomType;
 use rand::rngs::SmallRng;
 use rand::{RngCore, SeedableRng};
 #[cfg(all(feature="std", feature="nightly"))]
+use std::lazy::SyncLazy;
+#[cfg(all(feature="std", feature="nightly"))]
 use std::ops::Deref;
 #[cfg(all(feature="std", feature="nightly"))]
 use std::sync::Mutex;
@@ -476,7 +477,7 @@ impl<C: Component> IndexMut<Id<C>> for Arena<C> {
 /// # }
 /// ```
 #[cfg(all(feature="std", feature="nightly"))]
-pub struct ComponentClassMutex<C: ComponentClass>(sync::Lazy<Mutex<ComponentClassToken<C>>>);
+pub struct ComponentClassMutex<C: ComponentClass>(SyncLazy<Mutex<ComponentClassToken<C>>>);
 
 #[cfg(all(feature="std", feature="nightly"))]
 impl<C: ComponentClass> ComponentClassMutex<C> {
@@ -484,7 +485,7 @@ impl<C: ComponentClass> ComponentClassMutex<C> {
     ///
     /// The function is `const`, and can be used for static initialization.
     pub const fn new() -> Self {
-        ComponentClassMutex(sync::Lazy::new(|| Mutex::new(
+        ComponentClassMutex(SyncLazy::new(|| Mutex::new(
             ComponentClassToken::new().expect("component class token already crated")
         )))
     }
@@ -747,7 +748,8 @@ mod test {
     static TEST: ComponentClassMutex<Test> = ComponentClassMutex::new();
 
     #[quickcheck]
-    fn new_arena_min_capacity_is_zero(capacity: Option<usize>) -> bool {
+    fn new_arena_min_capacity_is_zero(capacity: Option<u8>) -> bool {
+        let capacity = capacity.map(|capacity| capacity as usize);
         capacity.map_or_else(
             || <Arena::<Test>>::new(&mut TEST.lock().unwrap()),
             |capacity| <Arena::<Test>>::with_capacity(capacity, &mut TEST.lock().unwrap())
@@ -755,7 +757,8 @@ mod test {
     }
 
     #[quickcheck]
-    fn arena_contains_inserted_item(capacity: Option<usize>, value: i8) -> bool {
+    fn arena_contains_inserted_item(capacity: Option<u8>, value: i8) -> bool {
+        let capacity = capacity.map(|capacity| capacity as usize);
         let mut arena = capacity.map_or_else(
             || Arena::new(&mut TEST.lock().unwrap()),
             |capacity| Arena::with_capacity(capacity, &mut TEST.lock().unwrap())
